@@ -552,7 +552,6 @@ class ExecutionServer(BaseServer):
             LOGGER.critical("No average speed to report yet.")
             
     def executeJobs(self, data=None):
-        deferreds = []
         while len(self.job_queue) > 0 and len(self.active_jobs) < self.simultaneous_jobs:
             job = self.job_queue.pop(0)
             exposed_function = job["exposed_function"]
@@ -561,20 +560,42 @@ class ExecutionServer(BaseServer):
             uuid = job["uuid"]
             del self.queued_jobs[uuid]
             # Call the function.
-            LOGGER.critical("Calling %s with args %s" % (function_name, kwargs))
+            LOGGER.debug("Calling %s with args %s" % (function_name, kwargs))
             # Schedule the next request.
-            d = self.callExposedFunction(
-                exposed_function["function"], 
+            self._callExposedFunction(
+                exposed_function["function"],
+                exposed_function["interval"], 
                 kwargs, 
                 function_name, 
                 uuid=uuid,
                 reservation_fast_cache=job["reservation_cache"])
-            d.addCallback(self._jobCountCallback)
-            d.addErrback(self._jobCountErrback)
-            d.addCallback(self._setNextRequest, uuid, exposed_function["interval"], function_name)
-            deferreds.append(d)
-        d = DeferredList(deferreds, consumeErrors=True)
-        d.addCallback(self._sendReservationUpdateQueue)
+                
+            #reactor.callInThread(
+            #    self._callExposedFunction, 
+            #    exposed_function["function"],
+            #    exposed_function["interval"], 
+            #    kwargs, 
+            #    function_name, 
+            #    uuid=uuid,
+            #    reservation_fast_cache=job["reservation_cache"])
+
+    def _callExposedFunction(
+        self, 
+        func, 
+        interval,
+        kwargs, 
+        function_name, 
+        uuid=None, 
+        reservation_fast_cache=None):
+        d = self.callExposedFunction(
+            func, 
+            kwargs, 
+            function_name, 
+            uuid=uuid,
+            reservation_fast_cache=reservation_fast_cache)
+        d.addCallback(self._jobCountCallback)
+        d.addErrback(self._jobCountErrback)
+        d.addCallback(self._setNextRequest, uuid, interval, function_name)
         
     def _jobCountCallback(self, data):
         self.job_count += 1
@@ -594,13 +615,15 @@ class ExecutionServer(BaseServer):
         self.reservation_update_queue.append((
             uuid,
             reservation_next_request_parameters))
+        if len(self.reservation_update_queue) > 25:
+            self._sendReservationUpdateQueue()
     
     def _sendReservationUpdateQueue(self, data=None):
         if len(self.reservation_update_queue) < 25 and (len(self.active_jobs) > 0 or len(self.job_queue) > 0):
             return
         if len(self.reservation_update_queue) == 0:
             return
-        LOGGER.debug("Sending reservation queue. Current length is %s" % (
+        LOGGER.critical("Sending reservation queue. Current length is %s" % (
             len(self.reservation_update_queue)))
         reservation_updates = self.reservation_update_queue[0:25]
         replace=["reservation_next_request", "reservation_cache"]
